<?php

class Dbmc_Admin {

	/**
	 * The ID of this plugin
	 * @var string
	 */
	private $dbmc;

	/**
	 * The version of this plugin
	 * @var string
	 */
	private $version;

	/**
	 * Initialize the class and set its properties
	 * @param string $dbmc     The name of this plugin
	 * @param string $version The version of this plugin
	 */
	public function __construct( $dbmc, $version ) {

		$this->dbmc = $dbmc;
		$this->version = $version;
	}

	/**
	 * Register the admin menu
	 */
	public function add_plugin_admin_menu() {

		add_menu_page(
			__( 'Mailchimp API', $this->dbmc ),
			__( 'Mailchimp API', $this->dbmc ),
			'manage_options',
			$this->dbmc,
			array( $this, 'display_dbmc_admin_page' ),
			'dashicons-email'
			);

		$tabs = Dbmc_Settings_Definition::get_tabs();

		foreach ( $tabs as $tab_slug => $tab_title ) {

			add_submenu_page(
				$this->dbmc,
				$tab_title,
				$tab_title,
				'manage_options',
				$this->dbmc . '&tab=' . $tab_slug,
				array( $this, 'display_dbmc_admin_page' )
				);
		}

		remove_submenu_page( $this->dbmc, $this->dbmc );
	}

	/**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 * @return   array 			Action links
	 */
	
	/**
	 * Setup the admin action links
	 * @param array $links Existing array of admin links
	 */
	public function add_action_links( $links ) {

		return array_merge(
			array(
				'settings' => '<a href="' . admin_url( 'admin.php?page=' . $this->dbmc ) . '">' . __( 'Settings', $this->dbmc ) . '</a>'
				),
			$links
			);

	}

	/**
	 * Render the settings page
	 * @return html Show the admin setting partial
	 */
	public function display_dbmc_admin_page() {

		$tabs = Dbmc_Settings_Definition::get_tabs();

		$default_tab = Dbmc_Settings_Definition::get_default_tab_slug();

		$active_tab = ( isset( $_GET[ 'tab' ] ) AND array_key_exists( $_GET['tab'], $tabs ) ) ? $_GET[ 'tab' ] : $default_tab;

		include_once( 'partials/' . $this->dbmc . '-admin-display.php' );

	}
}
