<?php

class Dbmc_Callback_Helper {

	/**
	 * The name of this plugin
	 * @var string
	 */
	private $dbmc;

	/**
	 * Initialize the class and set its properties
	 * @param string $dbmc The name of this plugin
	 */
	public function __construct( $dbmc ) {

		$this->dbmc = $dbmc;

	}

	/**
	 * Get the id attribute
	 * @param  string $id The id for the attribute to get
	 * @return string     The html part for the id
	 */
	private function get_id_attribute( $id ) {
	
		return ' id="dbmc_settings[' . $id . ']" ';
	
	}

	/**
	 * Get the name attribute
	 * @param  string $name The name for the attribute to get
	 * @return string       the html part for the nbame
	 */
	private function get_name_attribute( $name ) {
	
		return ' name="dbmc_settings[' . $name . ']" ';
	
	}

	/**
	 * Get the id and name attributes
	 * @param  string $field_key The field key
	 * @return string            The html for the id and name part
	 */
	private function get_id_and_name_attrubutes( $field_key ) {
	
		return  $this->get_id_attribute( $field_key ) . $this->get_name_attribute( $field_key );
	
	}

	/**
	 * Get the label
	 * @param  string $id   The id for the label
	 * @param  string $desc The description for the field
	 * @return string       Label html containing description
	 */
	private function get_label_for( $id, $desc ) {
	
		return '<label for="dbmc_settings[' . $id . ']"> '  . $desc . '</label>';
	
	}

	/**
	 * If a function is missing for settings callbacks alert the user
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Render the missing callback alert
	 */
	public function missing_callback( $args ) {
		
		printf( __( 'The callback function used for <strong>%s</strong> setting is missing.', $this->dbmc ), $args['id'] );
	
	}

	/**
	 * Renders the header
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Render the header HTML
	 */
	public function header_callback( $args ) {
	
		echo '<hr/>';
	
	}

	/**
	 * Renders the checkboxes
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Render the checkbox HTML
	 */
	public function checkbox_callback( $args ) {

		$value = Dbmc_Option::get_option( $args['id'] );
		$checked = isset( $value ) ? checked( 1, $value, false ) : '';

		$html = '<input type="checkbox" ';
		$html .= $this->get_id_and_name_attrubutes( $args['id'] );
		$html .= 'value="1" ' . $checked . '/>';

		$html .= '<br />';
		$html .= $this->get_label_for( $args['id'], $args['desc'] );

		echo $html;
	
	}

	/**
	 * Renders multiple checkboxes
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered HTML for multiple checkboxes
	 */
	public function multicheck_callback( $args ) {

		if ( empty( $args['options'] ) ) {
		
			printf( __( 'Options for <strong>%s</strong> multicheck is missing.', $this->dbmc ), $args['id'] );
			return;
		
		}

		$old_values = Dbmc_Option::get_option( $args['id'], array() );

		$html ='';

		foreach( $args['options'] as $field_key => $option ) {

			if ( isset( $old_values[ $field_key ] ) ) {
		
				$enabled = $option;
		
			} else {
		
				$enabled = NULL;
		
			}

			$checked = checked( $option, $enabled, false );

			$html .= '<input type="checkbox" ';
			$html .= $this->get_id_and_name_attrubutes( $args['id'] . '][' . $field_key );
			$html .= ' value="' . $option . '" ' . $checked . '/> ';

			$html .= $this->get_label_for( $args['id'] . '][' . $field_key, $option );
			$html .= '<br/>';

		}

		$html .= '<p class="description">' . $args['desc'] . '</p>';

		echo $html;
	
	}

	/**
	 * Renders radio boxes
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered radio box HTML
	 */
	public function radio_callback( $args ) {

		if ( empty( $args['options'] ) ) {
		
			printf( __( 'Options for <strong>%s</strong> radio is missing.', $this->dbmc ), $args['id'] );
			return;
		
		}

		$old_value = Dbmc_Option::get_option( $args['id'] );

		$html = '';

		foreach ( $args['options'] as $field_key => $option ) {

			if ( !empty( $old_value ) ) {
		
				$checked = checked( $field_key, $old_value,false );
		
			} else {
		
				$checked = checked( $args['std'], $field_key, false );
		
			}

			$html .= '<input type="radio"';
			$html .= $this->get_name_attribute( $args['id'] );
			$html .= $this->get_id_attribute( $args['id'] . '][' . $field_key );
			$html .= ' value="' . $field_key . '" ' . $checked . '/> ';

			$html .= $this->get_label_for( $args['id'] . '][' . $field_key, $option );
			$html .= '<br/>';

		}

		$html .= '<p class="description">' . $args['desc'] . '</p>';
	
		echo $html;
	
	}

	/**
	 * Renders text field
	 * @param  array  $args Arguments passed by the setting
	 */
	public function text_callback( $args ) {

		$this->input_type_callback( 'text', $args );

	}

	/**
	 * Render email field
	 * @param  array  $args Arguments passed by the setting
	 */
	public function email_callback( $args ) {

		$this->input_type_callback( 'email', $args );

	}

	/**
	 * Renders url fields
	 * @param  array  $args Arguments passed by the setting
	 */
	public function url_callback( $args ) {

		$this->input_type_callback( 'url', $args );

	}

	/**
	 * Renders password fields
	 * @param  array  $args Arguments passed by the setting
	 */
	public function password_callback( $args ) {

		$this->input_type_callback( 'password', $args );

	}

	/**
	 * Renders input type fields
	 * @param  string $type Input type
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered HTML for input type
	 */
	private function input_type_callback( $type, $args ) {

		$value = Dbmc_Option::get_option( $args['id'], $args['std']  );

		$html = '<input type="' . $type . '" ';
		$html .= $this->get_id_and_name_attrubutes( $args['id'] );
		$html .= 'class="' . $args['size'] . '-text" ';
		$html .= 'value="' . esc_attr( stripslashes( $value ) ) . '"/>';

		$html .= '<br />';
		$html .= $this->get_label_for( $args['id'], $args['desc'] );

		echo $html;

	}

	/**
	 * Renders number fields
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered HTML for the number field
	 */
	public function number_callback( $args ) {

		$value = Dbmc_Option::get_option( $args['id'] );

		$html = '<input type="number" ';
		$html .= $this->get_id_and_name_attrubutes( $args['id'] );
		$html .= 'class="' . $args['size'] . '-text" ';
		$html .= 'step="' . $args['step'] . '" ';
		$html .= 'max="' . $args['max'] . '" ';
		$html .= 'min="' . $args['min'] . '" ';
		$html .= 'value="' . $value . '"/>';

		$html .= '<br />';
		$html .= $this->get_label_for( $args['id'], $args['desc'] );

		echo $html;

	}

	/**
	 * Renders textarea field
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered HTML for the textarea field
	 */
	public function textarea_callback( $args ) {

		$value = Dbmc_Option::get_option( $args['id'], $args['std']  );

		$html = '<textarea ';
		$html .= 'class="' . $args['size'] . '-text" ';
		$html .= 'cols="50" rows="5" ';
		$html .= $this->get_id_and_name_attrubutes( $args['id'] ) . '>';
		$html .= esc_textarea( stripslashes( $value ) );
		$html .= '</textarea>';

		$html .= '<br />';
		$html .= $this->get_label_for( $args['id'], $args['desc'] );

		echo $html;

	}

	/**
	 * Renders select field
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered HTML for select field
	 */
	public function select_callback( $args ) {

		$value = Dbmc_Option::get_option( $args['id'] );

		$html = '<select ' . $this->get_id_and_name_attrubutes( $args['id'] ) . '/>';

			foreach ( $args['options'] as $option => $option_name ) {
				$selected = selected( $option, $value, false );
				$html .= '<option value="' . $option . '" ' . $selected . '>' . $option_name . '</option>';
			}

		$html .= '</select>';
		$html .= '<br />';
		$html .= $this->get_label_for( $args['id'], $args['desc'] );

		echo $html;

	}

	/**
	 * Renders rich editor fields
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered HTML for the rich editor field
	 */
	public function rich_editor_callback( $args ) {
		
		global $wp_version;

		$value = Dbmc_Option::get_option( $args['id'] );

		if ( $wp_version >= 3.3 AND function_exists( 'wp_editor' ) ) {
		
			ob_start();
			wp_editor( stripslashes( $value ), 'dbmc_settings_' . $args['id'], array( 'textarea_name' => 'dbmc_settings[' . $args['id'] . ']' ) );
			$html = ob_get_clean();
		
		} else {
		
			$html = '<textarea' . $this->get_id_and_name_attrubutes( $args['id'] ) . 'class="' . $args['size'] . '-text" rows="10" >' . esc_textarea( stripslashes( $value ) ) . '</textarea>';
		
		}

		$html .= '<br/>';
		$html .= $this->get_label_for( $args['id'], $args['desc'] );
		$html .= '<br/>';

		echo $html;

	}

	/**
	 * Renders upload field
	 * @param  array  $args Arguments passed by the setting
	 * @return string       Rendered HTML for the upload field
	 */
	public function upload_callback( $args ) {

		$html = '<input type="text" ';
		$html .= $this->get_id_and_name_attrubutes( $args['id'] );
		$html .= 'class="' . $args['size'] . '-text ' . 'dbmc_upload_field" ';
		$html .= ' value="' . esc_attr( stripslashes( $value ) ) . '"/>';

		$html .= '<span>&nbsp;<input type="button" class="' .  'dbmc_settings_upload_button button-secondary" value="' . __( 'Upload File', $this->dbmc ) . '"/></span>';

		$html .= $this->get_label_for( $args['id'], $args['desc'] );

		echo $html;

	}
}
