<?php

class Dbmc_Settings_Definition {

	/**
	 * The name of this plugin
	 * @var string
	 */
	public static $dbmc = 'dbmc';

	/**
	 * Apply the filters for the tab slug
	 * @param  array $default_settings Array containing the tab slugs
	 * @return array                   Array containing the filtered tab slugs
	 */
	static private function apply_tab_slug_filters( $default_settings ) {

		$extended_settings[] = array();
		$extended_tabs       = self::get_tabs();

		foreach ( $extended_tabs as $tab_slug => $tab_desc ) {

			$options = isset( $default_settings[ $tab_slug ] ) ? $default_settings[ $tab_slug ] : array();

			$extended_settings[ $tab_slug ] = apply_filters( 'dbmc_settings_' . $tab_slug, $options );
	
		}

		return $extended_settings;
	
	}

	/**
	 * Get the default tab
	 * @return string The default tab (open on page load)
	 */
	static public function get_default_tab_slug() {

		return key( self::get_tabs() );
	
	}

	/**
	 * Retrieve settings tab
	 * @return array Array containing the settings tab
	 */
	static public function get_tabs() {

		$tabs = array();
		$tabs['settings_tab'] = __( 'Settings', self::$dbmc );
		$tabs['lists_tab'] = __( 'Lists', self::$dbmc );

		return apply_filters( 'dbmc_settings_tabs', $tabs );
	
	}

	/**
	 * Definition of the tabs and the fields, can also be extended with own settings
	 * @return mixed Value saved or $default when key does not exist
	 */
	static public function get_settings() {

		$settings[] = array();

		$settings = array(
			'settings_tab' => array(
				'header_auth' => array(
					'name' => '<strong>' . __( 'Auth', self::$dbmc ) . '</strong>',
					'type' => 'header'
					),
				'dbmc_api_key' => array(
					'name' => __( 'API Key', self::$dbmc ),
					'type' => 'text'
					)
				),
			'lists_tab' => array(
				'header_default_contact' => array(
					'name' => '<strong>' . __( 'Default contact', self::$dbmc ) . '</strong>',
					'type' => 'header'
					),
				'dbmc_contact_company' => array(
					'name' => __( 'Company', self::$dbmc ),
					'type' => 'text'
					),
				'dbmc_contact_address1' => array(
					'name' => __( 'Address 1', self::$dbmc ),
					'type' => 'text'
					),
				'dbmc_contact_city' => array(
					'name' => __( 'City', self::$dbmc ),
					'type' => 'text'
					),
				'dbmc_contact_state' => array(
					'name' => __( 'State', self::$dbmc ),
					'type' => 'text'
					),
				'dbmc_contact_zip' => array(
					'name' => __( 'ZIP', self::$dbmc ),
					'type' => 'text'
					),
				'dbmc_contact_country' => array(
					'name' => __( 'Country', self::$dbmc ),
					'type' => 'text'
					),
				'header_campaign_defaults' => array(
					'name' => '<strong>' . __( 'Campaign defaults', self::$dbmc ) . '</strong>',
					'type' => 'header'
					),
				'dbmc_campaign_from_name' => array(
					'name' => __( 'From name', self::$dbmc ),
					'type' => 'text'
					),
				'dbmc_campaign_from_email' => array(
					'name' => __( 'From email address', self::$dbmc ),
					'type' => 'email'
					),
				'dbmc_campaign_subject' => array(
					'name' => __( 'Subject', self::$dbmc ),
					'type' => 'text'
					),
				'dbmc_campaign_language' => array(
					'name' => __( 'Language', self::$dbmc ),
					'type' => 'text'
					),
				)
			);

		return self::apply_tab_slug_filters( $settings );
	
	}
	
}
