<?php

class Dbmc_Settings {

	/**
	 * The name of this plugin
	 * @var string
	 */
	private $dbmc;

	/**
	 * The version of this plugin
	 * @var string
	 */
	private $version;

	/**
	 * The array of the plugin settings
	 * @var array
	 */
	private $registered_settings;

	/**
	 * The callback helper to render HTML elements for the setting forms
	 * @var Dbmc_Callback_Helper
	 */
	protected $callback;

	/**
	 * The sanitization helper to sanitize and validate settings
	 * @var Dbmc_Sanitization_Helper
	 */
	protected $sanitization;

	/**
	 * Initialize the class and set its properties
	 * @param string                  $dbmc                   The name of this plugin
	 * @param Dbmc_Callback_Helper     $settings_callback     he callback helper for rendering HTML markups
	 * @param Dbmc_Sanitization_Helper $settings_sanitization The sanitization helper for sanitizing settings
	 */
	public function __construct( $dbmc, $settings_callback, $settings_sanitization ) {

		$this->dbmc = $dbmc;
		$this->callback = $settings_callback;
		$this->sanitization = $settings_sanitization;
		$this->registered_settings = Dbmc_Settings_Definition::get_settings();
	
	}

	/**
	 * Register all settings sections and fields
	 */
	public function register_settings() {

		if ( false == get_option( 'dbmc_settings' ) ) {
	
			add_option( 'dbmc_settings', array(), '', 'yes' );
	
		}

		foreach( $this->registered_settings as $tab => $settings ) {

			add_settings_section(
				'dbmc_settings_' . $tab,
				__return_null(),
				'__return_false',
				'dbmc_settings_' . $tab
				);

			foreach ( $settings as $key => $option ) {

				$_name = isset( $option['name'] ) ? $option['name'] : $key;

				add_settings_field(
					'dbmc_settings[' . $key . ']',
					$_name,
					method_exists( $this->callback, $option['type'] . '_callback' ) ? array( $this->callback, $option['type'] . '_callback' ) : array( $this->callback, 'missing_callback' ),
					'dbmc_settings_' . $tab,
					'dbmc_settings_' . $tab,
					array(
						'id'      => $key,
						'desc'    => !empty( $option['desc'] ) ? $option['desc'] : '',
						'name'    => $_name,
						'section' => $tab,
						'size'    => isset( $option['size'] ) ? $option['size'] : 'regular',
						'options' => isset( $option['options'] ) ? $option['options'] : '',
						'std'     => isset( $option['std'] ) ? $option['std'] : '',
						'max'    => isset( $option['max'] ) ? $option['max'] : 999999,
						'min'    => isset( $option['min'] ) ? $option['min'] : 0,
						'step'   => isset( $option['step'] ) ? $option['step'] : 1,
						)
					);
			
			}

		}

		register_setting( 'dbmc_settings', 'dbmc_settings', array( $this->sanitization, 'settings_sanitize' ) );

	}
}
