<?php

class Dbmc_Option {

	/**
	 * Get an option
	 * @param  string  $key     The key value of the option
	 * @param  boolean $default The default value of the option
	 * @return mixed            Value saved / $default if key does not exist
	 */
	static public function get_option( $key, $default = false ) {

		if ( empty( $key ) ) {
		
			return $default;
		
		}

		$plugin_options = get_option( 'dbmc_settings', array() );

		$value = isset( $plugin_options[ $key ] ) ? $plugin_options[ $key ] : $default;

		return $value;
	}

	/**
	 * Updates the specified option
	 * @param  string $key   The key value of the option
	 * @param  string $value The value to be updated
	 * @return boolean       Returns true or false
	 */
	static public function update_option( $key, $value ) {

		if ( empty( $key ) ) {
		
			return false;
		
		}

		// Load the options
		$plugin_options = get_option( 'dbmc_settings', array() );

		// Update the specified value in the array
		$plugin_options[ $key ] = $value;

		// Save the options back to the DB
		return update_option( 'dbmc_settings', $plugin_options );
	}

	/**
	 * Deletes the specified option
	 * @param  string $key The key value of the option
	 * @return boolean     Returns true or false
	 */
	static public function delete_option( $key ) {

		if ( empty( $key ) ) {
	
			return false;
	
		}

		// Load the options
		$plugin_options = get_option( 'dbmc_settings', array() );

		// Delete the specified key
		unset($plugin_options[ $key ]);

		// Save the options back to the DB
		return update_option( 'dbmc_settings', $plugin_options );
	}
}
