<?php

class Dbmc {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power the plugin
	 * @var Dbmc_Loader
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin
	 * @var string
	 */
	protected $dbmc;

	/**
	 * The current version of the plugin
	 * @var string
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin
	 */
	public function __construct() {

		$this->dbmc = 'dbmc';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_api_hooks();

	}

	/**
	 * Load the required dependencies of this plugin
	 */
	private function load_dependencies() {

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-dbmc-loader.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-dbmc-i18n.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-dbmc-option.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-dbmc-admin.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/settings/class-dbmc-callback-helper.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/settings/class-dbmc-meta-box.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/settings/class-dbmc-sanitization-helper.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/settings/class-dbmc-settings-definition.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/settings/class-dbmc-settings.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'api/class-dbmc-api.php';

		$this->loader = new Dbmc_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization
	 */
	private function set_locale() {

		$plugin_i18n = new Dbmc_i18n();
		$plugin_i18n->set_domain( $this->get_dbmc() );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin functionality
	 */
	private function define_admin_hooks() {

		$dbmc_admin = new Dbmc_Admin( $this->get_dbmc(), $this->get_version() );

		$this->loader->add_action( 'admin_menu', $dbmc_admin, 'add_plugin_admin_menu' );

		// Add an action link pointing to the options page
		$dbmc_basename = plugin_basename( plugin_dir_path( realpath( dirname( __FILE__ ) ) ) . $this->dbmc . '.php' );
		$this->loader->add_action( 'plugin_action_links_' . $dbmc_basename, $dbmc_admin, 'add_action_links' );

		// Setup the option page
		$settings_callback = new Dbmc_Callback_Helper( $this->dbmc );
		$settings_sanitization = new Dbmc_Sanitization_Helper( $this->dbmc );
		$dbmc_settings = new Dbmc_Settings( $this->get_dbmc(), $settings_callback, $settings_sanitization);
		$this->loader->add_action( 'admin_init' , $dbmc_settings, 'register_settings' );

		// Setup the metaboxes
		$dbmc_meta_box = new Dbmc_Meta_Box( $this->get_dbmc() );
		$this->loader->add_action( 'load-toplevel_page_' . $this->get_dbmc() , $dbmc_meta_box, 'add_meta_boxes' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 */
	private function define_api_hooks() {

		$dbmc_api = new Dbmc_Api( $this->get_dbmc(), $this->get_version() );

		$this->loader->add_action( 'dbmc_api_rest', $dbmc_api, 'rest', 1, 3 );
		$this->loader->add_action( 'dbmc_get_option', $dbmc_api, 'get_option', 1, 3 );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress
	 * @return [type] [description]
	 */
	public function run() {

		$this->loader->run();

	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality
	 * @return string The name of the plugin
	 */
	public function get_dbmc() {

		return $this->dbmc;

	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin
	 * @return Dbmc_Loader Orchestrates the hooks of the plugin
	 */
	public function get_loader() {

		return $this->loader;

	}

	/**
	 * Retrieve the version number of the plugin
	 * @return string The version number of the plugin
	 */
	public function get_version() {

		return $this->version;

	}

}
